/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * FileSuffixValidator.cpp
 *
 *  Created on: May 14, 2012
 *      Author: ankele
 */


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include <boost/filesystem.hpp>
#include "FileSuffixValidator.hpp"

#include "CodePatterns/Log.hpp"

bool FileSuffixValidator::isValid(const boost::filesystem::path & _value) const
{
  const std::string dotted_suffix = std::string(".")+suffix;
  LOG(2, "DEBUG: FileSuffixValidator compares " << _value.extension() << " with " << dotted_suffix << ".");
  return _value.extension() == dotted_suffix;
}

bool FileSuffixValidator::operator==(const Validator<boost::filesystem::path> &_instance) const
{
  const FileSuffixValidator *inst =
      dynamic_cast<const FileSuffixValidator *>(&_instance);
  if (inst)
    return (suffix == inst->suffix);
  else
    return false;
}

Validator< boost::filesystem::path >* FileSuffixValidator::clone() const
{
  Validator< boost::filesystem::path > *inst =
      new FileSuffixValidator(suffix);
  return inst;
}




